@@ -1,8 +1,12 @@
 #include <math.h>
 
 int isnan(double d) {
-  unsigned long long *x=(unsigned long long *)&d;
-  return (*x==0x7FF8000000000000ll || *x==0x7FF0000000000000 || *x==0xfff8000000000000);
+  union {
+    unsigned long long l;
+    double d;
+  } u;
+  u.d=d;
+  return (u.l==0x7FF8000000000000ll || u.l==0x7FF0000000000000ll || u.l==0xfff8000000000000ll);
 }
 int __isnan(double d) __attribute__((alias("isnan")));
 
