@@ -7,37 +7,42 @@
 #include "dietstdio.h"
 #include "dietwarning.h"
 
-static inline unsigned int skip_to(const char *format) {
-  unsigned int nr;
+#define MAX_WIDTH 10*1024
+
+static inline unsigned long skip_to(const char *format) {
+  unsigned long nr;
   for (nr=0; format[nr] && (format[nr]!='%'); ++nr);
   return nr;
 }
 
 #define A_WRITE(fn,buf,sz)	((fn)->put((void*)(buf),(sz),(fn)->data))
+#define B_WRITE(fn,buf,sz)	{ if ((unsigned long)(sz) > (((unsigned long)(int)(-1))>>1) || len+(int)(sz)<len) return -1; A_WRITE(fn,buf,sz); } while (0)
 
 static const char pad_line[2][16]= { "                ", "0000000000000000", };
-static inline int write_pad(struct arg_printf* fn, int len, int padwith) {
+static int write_pad(unsigned int* dlen,struct arg_printf* fn, unsigned int len, int padwith) {
   int nr=0;
+  if ((int)len<0 || *dlen+len<len) return -1;
   for (;len>15;len-=16,nr+=16) {
     A_WRITE(fn,pad_line[(padwith=='0')?1:0],16);
   }
   if (len>0) {
     A_WRITE(fn,pad_line[(padwith=='0')?1:0],(unsigned int)len); nr+=len;
   }
-  return nr;
+  *dlen += nr;
+  return 0;
 }
 
 int __v_printf(struct arg_printf* fn, const char *format, va_list arg_ptr)
 {
-  int len=0;
+  unsigned int len=0;
 #ifdef WANT_ERROR_PRINTF
   int _errno = errno;
 #endif
 
   while (*format) {
-    unsigned int sz = skip_to(format);
+    unsigned long sz = skip_to(format);
     if (sz) {
-      A_WRITE(fn,format,sz); len+=sz;
+      B_WRITE(fn,format,sz); len+=sz;
       format+=sz;
     }
     if (*format=='%') {
@@ -46,7 +51,7 @@ int __v_printf(struct arg_printf* fn, const char *format, va_list arg_ptr)
 #define s u_str.s
 
       int retval;
-      unsigned char ch, padwith=' ';
+      unsigned char ch, padwith=' ', precpadwith=' ';
 
       char flag_in_sign=0;
       char flag_upcase=0;
@@ -81,9 +86,15 @@ inn_printf:
       case 'h':
 	--flag_long;
 	goto inn_printf;
+#if __WORDSIZE != 64
+      case 'j':
+#endif
       case 'q':		/* BSD ... */
       case 'L':
 	++flag_long; /* fall through */
+#if __WORDSIZE == 64
+      case 'j':
+#endif
       case 'l':
 	++flag_long;
 	goto inn_printf;
@@ -112,12 +123,14 @@ inn_printf:
       case '9':
 	if(flag_dot) return -1;
 	width=strtoul(format-1,(char**)&s,10);
+	if (width>MAX_WIDTH) return -1;
 	if (ch=='0' && !flag_left) padwith='0';
 	format=s;
 	goto inn_printf;
 
       case '*':
 	width=va_arg(arg_ptr,int);
+	if (width>MAX_WIDTH) return -1; /* width is unsiged, so this catches <0, too */
 	goto inn_printf;
 
       case '.':
@@ -131,13 +144,14 @@ inn_printf:
 	  preci=tmp<0?0:tmp;
 	  format=s;
 	}
+	if (preci>MAX_WIDTH) return -1;
 	goto inn_printf;
 
       /* print a char or % */
       case 'c':
 	ch=(char)va_arg(arg_ptr,int);
       case '%':
-	A_WRITE(fn,&ch,1); ++len;
+	B_WRITE(fn,&ch,1); ++len;
 	break;
 
 #ifdef WANT_ERROR_PRINTF
@@ -145,7 +159,7 @@ inn_printf:
       case 'm':
 	s=strerror(_errno);
 	sz=strlen(s);
-	A_WRITE(fn,s,sz); len+=sz;
+	B_WRITE(fn,s,sz); len+=sz;
 	break;
 #endif
       /* print a string */
@@ -158,7 +172,7 @@ inn_printf:
 	if (flag_dot && sz>preci) sz=preci;
 	preci=0;
 	flag_dot^=flag_dot;
-	padwith=' ';
+	padwith=precpadwith=' ';
 
 print_out:
       {
@@ -167,7 +181,7 @@ print_out:
 	int vs;
 	
 	if (! (width||preci) ) {
-	  A_WRITE(fn,s,sz); len+=sz;
+	  B_WRITE(fn,s,sz); len+=sz;
 	  break;
 	}
 	
@@ -178,40 +192,46 @@ print_out:
 	  sz-=todo;
 	  width-=todo;
 	}
-	
-	if (!flag_left) {
-	  if (flag_dot) {
-	    vs=preci>sz?preci:sz;
-	    len+=write_pad(fn,(signed int)width-(signed int)vs,' ');
-	    if (todo) {
-	      A_WRITE(fn,sign,todo);
-	      len+=todo;
-	    }
-	    len+=write_pad(fn,(signed int)preci-(signed int)sz,'0');
-	  } else {
-	    if (todo && padwith=='0') {
-	      A_WRITE(fn,sign,todo);
-	      len+=todo; todo=0;
-	    }
-	    len+=write_pad(fn,(signed int)width-(signed int)sz, padwith);
-	    if (todo) {
-	      A_WRITE(fn,sign,todo);
-	      len+=todo;
-	    }
-	  }
-	  A_WRITE(fn,s,sz); len+=sz;
-	} else if (flag_left) {
-	  if (todo) {
-	    A_WRITE(fn,sign,todo);
-	    len+=todo;
-	  }
-	  len+=write_pad(fn,(signed int)preci-(signed int)sz, '0');
-	  A_WRITE(fn,s,sz); len+=sz;
-	  vs=preci>sz?preci:sz;
-	  len+=write_pad(fn,(signed int)width-(signed int)vs, ' ');
-	} else {
-	  A_WRITE(fn,s,sz); len+=sz;
+
+	/* These are the cases for 1234 or "1234" respectively:
+	      %.6u -> "001234"
+	      %6u  -> "  1234"
+	      %06u -> "001234"
+	      %-6u -> "1234  "
+	      %.6s -> "1234"
+	      %6s  -> "  1234"
+	      %06s -> "  1234"
+	      %-6s -> "1234  "
+	      %6.5u -> " 01234"
+	      %6.5s -> "  1234"
+           In this code, for %6.5s, 6 is width, 5 is preci.
+	   flag_dot means there was a '.' and preci is set.
+	   flag_left means there was a '-'.
+	   sz is 4 (strlen("1234")).
+	   padwith will be '0' for %06u, ' ' otherwise.
+	   precpadwith is '0' for %u, ' ' for %s.
+	 */
+
+	if (flag_dot && width==0) width=preci;
+	if (!flag_dot) preci=sz;
+	if (!flag_left) { /* do left-side padding */
+	  if (write_pad(&len,fn,width-preci,padwith))
+	    return -1;
 	}
+	if (todo) {
+	  B_WRITE(fn,sign,todo);
+	  len+=todo;
+	}
+	/* do preci padding */
+	if (write_pad(&len,fn,preci-sz,precpadwith))
+	  return -1;
+	/* write actual string */
+	B_WRITE(fn,s,sz); len+=sz;
+	if (flag_left) {
+	  if (write_pad(&len,fn,width-preci,padwith))
+	    return -1;
+	}
+	
 	break;
       }
 
@@ -264,8 +284,11 @@ num_printf:
 #endif
 	    number=va_arg(arg_ptr,long);
 	}
-	else
+	else {
 	  number=va_arg(arg_ptr,int);
+	  if (sizeof(int) != sizeof(long) && !flag_in_sign)
+	    number&=((unsigned int)-1);
+	}
 
 	if (flag_in_sign) {
 #ifdef WANT_LONGLONG_PRINTF
@@ -304,6 +327,8 @@ num_printf:
 	  ++sz;
 	} else flag_in_sign=0;
 
+	precpadwith='0';
+
 	goto print_out;
 
 #ifdef WANT_FLOATING_POINT_IN_PRINTF
@@ -317,9 +342,9 @@ num_printf:
 	  if (width==0) width=1;
 	  if (!flag_dot) preci=6;
 	  if (flag_sign || d < +0.0) flag_in_sign=1;
-	  
-	  sz=__dtostr(d,s,sizeof(buf)-1,width,preci);
-	  
+
+	  sz=__dtostr(d,s,sizeof(buf)-1,width,preci,g);
+
 	  if (flag_dot) {
 	    char *tmp;
 	    if ((tmp=strchr(s,'.'))) {
@@ -351,6 +376,8 @@ num_printf:
 	  }
 	  
 	  sz=strlen(s);
+	  if (width<sz) width=sz;
+	  padwith='0';
 	  flag_dot=0;
 	  flag_hash=0;
 	  goto print_out;
@@ -366,4 +393,3 @@ num_printf:
 }
 
 link_warning("__v_printf","warning: the printf functions add several kilobytes of bloat.")
-
