@@ -4,10 +4,7 @@
 #include <pthread.h>
 #include "thread_internal.h"
 
-int pthread_attr_getdetachstate(const pthread_attr_t *attr, int *detachstate)
-{
-  __THREAD_INIT();
-
+int pthread_attr_getdetachstate(const pthread_attr_t*attr,int*detachstate) {
   *detachstate=attr->__detachstate;
   return 0;
 }
