@@ -5,6 +5,7 @@ void blah(void) {
   write(2,"atexit\n",7);
 }
 
-main() {
+int main() {
   atexit(blah);
+  return 0;
 }
