@@ -1,6 +1,10 @@
 #include <sys/types.h>
+#include <sys/socket.h>
 #include <linuxnet.h>
 
+int __libc_send(int fd, const void * buf, size_t n, int flags);
+  /* shut up gcc warning about missing prototype */
+
 int __libc_send(int fd, const void * buf, size_t n, int flags) {
   return sendto(fd, buf, n, flags, NULL, 0);
 }
